// Copyright 2023-2024 Gentoo Authors
// Distributed under the terms of the GNU General Public License v2

var target = Argument("target", "pack");
var configuration = Argument("configuration", "Release");

var pwshRunner = $"tool run pwsh -NoLogo -NoProfile -NonInteractive";

var admin = System.IO.Path.GetFullPath("./admin");
var dotnetWrapper = System.IO.Path.Combine(admin, "dotnet_wrapper.sh");

Task("create-tools-list")
    .Does(() =>
    {
        StartProcess(dotnetWrapper, new ProcessSettings {
                Arguments = $"{pwshRunner} {admin}/create_tools_list.ps1"
            });
    });

Task("format")
    .Does(() =>
    {
        StartProcess(dotnetWrapper, new ProcessSettings {
                Arguments = $"{pwshRunner} {admin}/format_fs.ps1"
            });
    });

Task("clean")
    .Does(() =>
    {
        StartProcess(dotnetWrapper, new ProcessSettings {
                Arguments = "clean --verbosity quiet"
            });

        CleanDirectory(".cache/nupkg");
    });

Task("build")
    .Does(() =>
    {
        StartProcess(dotnetWrapper, new ProcessSettings {
                Arguments = $"build --configuration {configuration}"
            });
    });

Task("debug")
    .Does(() =>
    {
        StartProcess(dotnetWrapper, new ProcessSettings {
                Arguments = $"{pwshRunner} {admin}/build_debug.ps1"
            });
    });

Task("test")
    .IsDependentOn("build")
    .Does(() =>
    {
        StartProcess(dotnetWrapper, new ProcessSettings {
                Arguments = $"test --configuration {configuration}"
            });
    });

Task("pack")
    .IsDependentOn("build")
    .Does(() =>
    {
        StartProcess(dotnetWrapper, new ProcessSettings {
                Arguments = $"pack --configuration {configuration}"
            });
    });

Task("install")
    .IsDependentOn("pack")
    .Does(() =>
    {
        var tools = new[] {
            "Gdmt.Checkcore",
            "Gdmt.CleanTmp",
            "Gdmt.Commit",
            "Gdmt.Ebuild",
            "Gdmt.Genpwsh",
            "Gdmt.Gensdk",
            "Gdmt.Govendor",
            "Gdmt.PackageName",
            "Gdmt.Restore",
            "Gdmt.StableRequest",
            "Gdmt.Sync"
        };

        foreach (var tool in tools)
        {
            Information($"Reinstalling tool: {tool}");

            StartProcess(dotnetWrapper, new ProcessSettings {
                    Arguments = $"{pwshRunner} {admin}/reinstall_tool.ps1 {tool}"
                });
        }
    });

Task("before-commit")
    .IsDependentOn("clean")
    .IsDependentOn("create-tools-list")
    .IsDependentOn("format")
    .IsDependentOn("debug")
    .IsDependentOn("pack");

RunTarget(target);
