// Copyright 2023-2024 Gentoo Authors
// Distributed under the terms of the GNU General Public License v2

namespace Gdmt.Shared.PackageName

module PackageName =
    open System
    open System.IO

    open Gdmt.Shared.SimpleLog

    let DoesHaveLayoutConf (path: string) : string * bool =
        let layoutPath = Path.Combine(path, "metadata/layout.conf")

        (layoutPath, File.Exists layoutPath)

    let GetFullPackageName (path: string) : string =
        let fullPath = path |> Path.GetFullPath

        let repoPath = fullPath |> Path.GetDirectoryName |> Path.GetDirectoryName

        match (DoesHaveLayoutConf repoPath) with
        | _, true -> ()
        | f, false ->
            SimpleLog.LogMessage SimpleLog.Error "layout.conf file could not be found"
            SimpleLog.LogMessage SimpleLog.Error $"Required layout.conf from this location: {f}"
            SimpleLog.LogMessage SimpleLog.Error "Probably wrong package path given"

            $"file not found: {f}" |> Exception |> raise

        let segments = fullPath.Split('/') |> Array.rev |> Array.toList

        match segments with
        | segment1 :: segment2 :: _ -> Path.Combine(segment2, segment1)
        | _ -> "wrong list length" |> Exception |> raise
