// Copyright 2023-2024 Gentoo Authors
// Distributed under the terms of the GNU General Public License v2

namespace Gdmt.Shared.SimpleLog

module SimpleLog =
    open System

    type MessageType =
        | Debug
        | Error
        | Success

    let LogMessage (messageType: MessageType) (messageContents: string) =
        let time = DateTime.Now.ToString("HH:mm:ss")

        let indicatorString =
            match messageType with
            | MessageType.Debug -> "DBG"
            | MessageType.Error -> "ERR"
            | _ -> "OK "

        let indicatorColor =
            match messageType with
            | MessageType.Debug -> ConsoleColor.Magenta
            | MessageType.Error -> ConsoleColor.Red
            | _ -> ConsoleColor.Green

        Console.ResetColor()

        Console.ForegroundColor <- ConsoleColor.DarkGray
        printf " [%s %s] " time indicatorString

        Console.ForegroundColor <- indicatorColor
        printfn "%s" messageContents

        Console.ResetColor()
